@@ -10,6 +10,7 @@
 #include <QFile>
 #include <codecs.cpp>
 
+using namespace Qt::Literals;
 using namespace KMime;
 
 QTEST_MAIN(MessageTest)
@@ -694,5 +695,31 @@ void MessageTest::testHeadersWithNullBytes()
     QCOMPARE(msg->headerByType("SubjectInvalid")->as7BitString().data(), "SubjectInvalid: This header type contains a null byte");
 }
 
+void MessageTest::testBigAllocation()
+{
+    KMime::Message::Ptr msg = readAndParseMail(QStringLiteral("big-allocation.mbox"));
+    QCOMPARE(msg->contents().size(), 20);
+    for (const auto &part : msg->contents()) {
+        QVERIFY(part->contents().empty());
+    }
+}
+
+void MessageTest::testGarbage_data()
+{
+    QTest::addColumn<QString>("filename");
+    QTest::newRow("multipart-parse-abort-1") << u"multipart-parse-abort.mbox"_s;
+    QTest::newRow("multipart-parse-abort-2") << u"multipart-parse-abort-2.mbox"_s;
+    QTest::newRow("digits-overflow") << u"read-digits-overflow.mbox"_s;
+    QTest::newRow("uninitialized-memory") << u"uninitialized-memory-use.mbox"_s;
+    QTest::newRow("infinite-memory") << u"clusterfuzz-testcase-minimized-kmime_fuzzer-5255984894509056"_s;
+}
+
+void MessageTest::testGarbage()
+{
+    // all this does is to ensure parsing the input file doesn't crash, trigger ASAN or infinitely loop
+    QFETCH(QString, filename);
+    KMime::Message::Ptr msg = readAndParseMail(filename);
+    QVERIFY(msg);
+}
 
 #include "moc_messagetest.cpp"
