@@ -1502,20 +1502,22 @@ bool Newsgroups::parse(const char *&scursor, const char *const send, bool isCRLF
     Q_D(Newsgroups);
     d->groups.clear();
     while (true) {
-      eatCFWS(scursor, send, isCRLF);
-      if (scursor != send && *scursor == ',') {
-        ++scursor;
-      }
-      eatCFWS(scursor, send, isCRLF);
-      if (scursor == send) {
-        return true;
-      }
-      const char *start = scursor;
-      while (scursor != send && !isspace(*scursor) && *scursor != ',') {
-        ++scursor;
-      }
-      QByteArray group(start, scursor - start);
-      d->groups.append(group);
+        eatCFWS(scursor, send, isCRLF);
+        if (scursor != send && *scursor == ',') {
+            ++scursor;
+        }
+        eatCFWS(scursor, send, isCRLF);
+        if (scursor == send) {
+            return true;
+        }
+        const char *start = scursor;
+        while (scursor != send && !isspace(*scursor) && *scursor != ',') {
+            ++scursor;
+        }
+        if (start != scursor) {
+            QByteArray group(start, scursor - start);
+            d->groups.append(group);
+        }
     }
     return true;
 }
