@@ -17,9 +17,6 @@
 
 //@cond PRIVATE
 
-#define kmime_mk_empty_private( subclass, base ) \
-    class subclass##Private : public base##Private {};
-
 namespace KMime
 {
 
@@ -59,31 +56,37 @@ public:
     QString decoded;
 };
 
-kmime_mk_empty_private(Structured, Base)
-kmime_mk_empty_private(Address, Structured)
+class StructuredPrivate : public BasePrivate {};
 
-class MailboxListPrivate : public AddressPrivate
+class MailboxListPrivate : public StructuredPrivate
 {
 public:
   QList<Types::Mailbox> mailboxList;
 };
 
-kmime_mk_empty_private(SingleMailbox, MailboxList)
+class SingleMailboxPrivate : public StructuredPrivate {
+public:
+    Types::Mailbox mailbox;
+};
 
-class AddressListPrivate : public AddressPrivate
+class AddressListPrivate : public StructuredPrivate
 {
 public:
     KMime::Types::AddressList addressList;
 };
 
-class IdentPrivate : public AddressPrivate
+class IdentPrivate : public StructuredPrivate
 {
 public:
     KMime::Types::AddrSpecList msgIdList;
-    mutable QByteArray cachedIdentifier;
 };
 
-kmime_mk_empty_private(SingleIdent, Ident)
+class SingleIdentPrivate : public StructuredPrivate
+{
+public:
+    KMime::Types::AddrSpec msgId;
+    mutable QByteArray cachedIdentifier;
+};
 
 class TokenPrivate : public StructuredPrivate
 {
@@ -111,7 +114,7 @@ public:
 
 } // namespace Generics
 
-class ReturnPathPrivate : public Generics::AddressPrivate
+class ReturnPathPrivate : public Generics::StructuredPrivate
 {
 public:
     Types::Mailbox mailbox;
@@ -120,13 +123,8 @@ public:
 class MailCopiesToPrivate : public Generics::AddressListPrivate
 {
 public:
-    MailCopiesToPrivate() :
-        Generics::AddressListPrivate(),
-        alwaysCopy(false),
-        neverCopy(false)
-    {}
-    bool alwaysCopy;
-    bool neverCopy;
+    bool alwaysCopy = false;
+    bool neverCopy = false;
 };
 
 class ContentTransferEncodingPrivate : public Generics::TokenPrivate
@@ -138,28 +136,18 @@ public:
 class ContentTypePrivate : public Generics::ParametrizedPrivate
 {
 public:
-    ContentTypePrivate() :
-        Generics::ParametrizedPrivate()
-    {}
     QByteArray mimeType;
 };
 
 class ContentDispositionPrivate : public Generics::ParametrizedPrivate
 {
 public:
-    ContentDispositionPrivate() :
-        Generics::ParametrizedPrivate(),
-        disposition(CDInvalid)
-    {}
-    contentDisposition disposition;
+    contentDisposition disposition = CDInvalid;
 };
 
 class GenericPrivate : public Generics::UnstructuredPrivate
 {
 public:
-    GenericPrivate() :
-        Generics::UnstructuredPrivate()
-    {}
     ~GenericPrivate()
     {
         delete[] type;
@@ -190,14 +178,10 @@ public:
 class LinesPrivate : public Generics::StructuredPrivate
 {
 public:
-    LinesPrivate() :
-        Generics::StructuredPrivate(),
-        lines(-1)
-    {}
-    int lines;
+    int lines = -1;
 };
 
-kmime_mk_empty_private(ContentID, Generics::SingleIdent)
+class ContentIDPrivate : public Generics::SingleIdentPrivate {};
 }
 
 }
